@@ -38,43 +38,43 @@
 #include <trng/correlated_normal_dist.hpp>
 
 double covariance(const std::vector<double> &v1, const std::vector<double> &v2) {
-  std::vector<double>::size_type n=v1.size();
-  double m1=0.0, m2=0.0, c=0.0;
-  for (std::vector<double>::size_type i=0; i<n; ++i) {
-    m1+=v1[i]/n;  m2+=v2[i]/n;
+  std::vector<double>::size_type n = v1.size();
+  double m1 = 0.0, m2 = 0.0, c = 0.0;
+  for (std::vector<double>::size_type i = 0; i < n; ++i) {
+    m1 += v1[i] / n;
+    m2 += v2[i] / n;
   }
-  for (std::vector<double>::size_type i=0; i<n; ++i) 
-    c+=(v1[i]-m1)*(v2[i]-m2)/n;
+  for (std::vector<double>::size_type i = 0; i < n; ++i)
+    c += (v1[i] - m1) * (v2[i] - m2) / n;
   return c;
 }
 
 int main() {
-  const int d=4;
+  const int d = 4;
   // covariance matrix
-  double sig[d][d] = { { 2.0, -0.5,  0.3, -0.3},
-		       {-0.5,  3.0, -0.3,  0.3},
-		       { 0.3, -0.3,  1.0, -0.3},
-		       {-0.3,  0.3, -0.3,  1.0} };
-  trng::correlated_normal_dist<> D(&sig[0][0], &sig[d-1][d-1]+1);
+  double sig[d][d] = {{2.0, -0.5, 0.3, -0.3},
+                      {-0.5, 3.0, -0.3, 0.3},
+                      {0.3, -0.3, 1.0, -0.3},
+                      {-0.3, 0.3, -0.3, 1.0}};
+  trng::correlated_normal_dist<> D(&sig[0][0], &sig[d - 1][d - 1] + 1);
   trng::lcg64 R;
 
   std::vector<double> x1, x2, x3, x4;
   // generate 4-tuples of correlated normal variables
-  for (int i=0; i<1000000; ++i) {
-    x1.push_back(D(R));  
-    x2.push_back(D(R));  
-    x3.push_back(D(R)); 
+  for (int i = 0; i < 1000000; ++i) {
+    x1.push_back(D(R));
+    x2.push_back(D(R));
+    x3.push_back(D(R));
     x4.push_back(D(R));
   }
   // print (empirical) covariance matrix
-  std::cout << std::setprecision(4)
-	    << covariance(x1, x1) << '\t' << covariance(x1, x2) << '\t'
-	    << covariance(x1, x3) << '\t' << covariance(x1, x4) << '\n'
-	    << covariance(x2, x1) << '\t' << covariance(x2, x2) << '\t'
-	    << covariance(x2, x3) << '\t' << covariance(x2, x4) << '\n'
-	    << covariance(x3, x1) << '\t' << covariance(x3, x2) << '\t'
-	    << covariance(x3, x3) << '\t' << covariance(x3, x4) << '\n'
-	    << covariance(x4, x1) << '\t' << covariance(x4, x2) << '\t'
-	    << covariance(x4, x3) << '\t' << covariance(x4, x4) << '\n';
+  std::cout << std::setprecision(4) << covariance(x1, x1) << '\t' << covariance(x1, x2) << '\t'
+            << covariance(x1, x3) << '\t' << covariance(x1, x4) << '\n'
+            << covariance(x2, x1) << '\t' << covariance(x2, x2) << '\t' << covariance(x2, x3)
+            << '\t' << covariance(x2, x4) << '\n'
+            << covariance(x3, x1) << '\t' << covariance(x3, x2) << '\t' << covariance(x3, x3)
+            << '\t' << covariance(x3, x4) << '\n'
+            << covariance(x4, x1) << '\t' << covariance(x4, x2) << '\t' << covariance(x4, x3)
+            << '\t' << covariance(x4, x4) << '\n';
   return EXIT_SUCCESS;
 }
