@@ -1,4 +1,3 @@
-#if __cplusplus > 201100L
 // mix random number generators and distribution from
 // TRNG and the C++11 standard library
 
@@ -13,7 +12,7 @@ int main() {
   trng::lcg64 R_trng;
   std::normal_distribution<> N_cpp11;
   trng::normal_dist<> N_trng(0, 1);
-  for (int i=0; i<10000; ++i) {
+  for (int i = 0; i < 10000; ++i) {
     std::cout << N_cpp11(R_cpp11) << '\t';
     std::cout << N_cpp11(R_trng) << '\t';
     std::cout << N_trng(R_cpp11) << '\t';
@@ -21,9 +20,3 @@ int main() {
   }
   return EXIT_SUCCESS;
 }
-#else
-#include <iostream>
-int main() {
-  std::cout << "Not a C++11 compiler.\n";
-}
-#endif
