@@ -52,20 +52,17 @@ int main() {
   trng::lcg64 r;
   // draw some random numbers
   std::vector<int> count(p.size(), 0);
-  const int samples=10000;
-  for (int i=0; i<samples; ++i) {
-    int x=dist(r);  // draw a random number
-    ++count[x];     // count
+  const int samples = 10000;
+  for (int i = 0; i < samples; ++i) {
+    int x = dist(r);  // draw a random number
+    ++count[x];       // count
   }
   // print results
   std::cout << "value\t\tprobability\tcount\t\tempirical probability\n"
-	    << "=====\t\t===========\t=====\t\t=====================\n";
-  for (std::vector<int>::size_type i=0; i<count.size(); ++i) {
-    std::cout << std::setprecision(3) 
-	      << i << "\t\t"
-	      << dist.pdf(i) << "\t\t"
-	      << count[i] << "\t\t"
-	      << static_cast<double>(count[i])/samples << '\n';
+            << "=====\t\t===========\t=====\t\t=====================\n";
+  for (std::vector<int>::size_type i = 0; i < count.size(); ++i) {
+    std::cout << std::setprecision(3) << i << "\t\t" << dist.pdf(static_cast<int>(i)) << "\t\t"
+              << count[i] << "\t\t" << static_cast<double>(count[i]) / samples << '\n';
   }
   return EXIT_SUCCESS;
 }
