@@ -1,22 +1,22 @@
 // Copyright (c) 2000-2019, Heiko Bauke
 // All rights reserved.
-// 
+//
 // Redistribution and use in source and binary forms, with or without
 // modification, are permitted provided that the following conditions
 // are met:
-// 
+//
 //   * Redistributions of source code must retain the above copyright
-//     notice, this list of conditions and the following disclaimer.  
-// 
+//     notice, this list of conditions and the following disclaimer.
+//
 //   * Redistributions in binary form must reproduce the above
 //     copyright notice, this list of conditions and the following
 //     disclaimer in the documentation and/or other materials provided
-//     with the distribution.  
-// 
+//     with the distribution.
+//
 //   * Neither the name of the copyright holder nor the names of its
 //     contributors may be used to endorse or promote products derived
 //     from this software without specific prior written permission.
-// 
+//
 // THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 // "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 // LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
@@ -30,9 +30,6 @@
 // ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 // OF THE POSSIBILITY OF SUCH DAMAGE.
 
-#include <trng/config.hpp>
-#if defined TRNG_HAVE_MPI
-
 #include <cstdlib>
 #include <iostream>
 #include "mpi.h"
@@ -40,42 +37,29 @@
 #include <trng/uniform01_dist.hpp>
 
 int main(int argc, char *argv[]) {
-  const long samples=1000000l;          // total number of points in square
-  trng::yarn2 rx, ry;                   // random number engines for x- and y-coordinates
-  MPI::Init(argc, argv);                // initialize MPI environment
-  int size=MPI::COMM_WORLD.Get_size();  // get total number of processes
-  int rank=MPI::COMM_WORLD.Get_rank();  // get rank of current process
+  const long samples = 1000000l;          // total number of points in square
+  trng::yarn2 rx, ry;                     // random number engines for x- and y-coordinates
+  MPI::Init(argc, argv);                  // initialize MPI environment
+  int size = MPI::COMM_WORLD.Get_size();  // get total number of processes
+  int rank = MPI::COMM_WORLD.Get_rank();  // get rank of current process
   // split PRN sequences by leapfrog method
-  rx.split(2, 0);                       // choose sub-stream no. 0 out of 2 streams
-  ry.split(2, 1);                       // choose sub-stream no. 1 out of 2 streams
-  rx.split(size, rank);                 // choose sub-stream no. rank out of size streams
-  ry.split(size, rank);                 // choose sub-stream no. rank out of size streams
-  long in=0l;                           // number of points in circle
-  trng::uniform01_dist<> u;             // random number distribution
+  rx.split(2, 0);            // choose sub-stream no. 0 out of 2 streams
+  ry.split(2, 1);            // choose sub-stream no. 1 out of 2 streams
+  rx.split(size, rank);      // choose sub-stream no. rank out of size streams
+  ry.split(size, rank);      // choose sub-stream no. rank out of size streams
+  long in = 0l;              // number of points in circle
+  trng::uniform01_dist<> u;  // random number distribution
   // throw random points into square and distribute workload over all processes
-  for (long i=rank; i<samples; i+=size) {
-    double x=u(rx), y=u(ry);            // choose random x- and y-coordinates
-    if (x*x+y*y<=1.0)                   // is point in circle?
-      ++in;                             // increase counter
+  for (long i = rank; i < samples; i += size) {
+    double x = u(rx), y = u(ry);  // choose random x- and y-coordinates
+    if (x * x + y * y <= 1.0)     // is point in circle?
+      ++in;                       // increase counter
   }
   // calculate sum of all local variables 'in' and storre result in 'in_all' on process 0
   long in_all;
   MPI::COMM_WORLD.Reduce(&in, &in_all, 1, MPI::LONG, MPI::SUM, 0);
-  if (rank==0)                          // print result 
-    std::cout << "pi = " << 4.0*in_all/samples << std::endl;
-  MPI::Finalize();                      // quit MPI
+  if (rank == 0)  // print result
+    std::cout << "pi = " << 4.0 * in_all / samples << std::endl;
+  MPI::Finalize();  // quit MPI
   return EXIT_SUCCESS;
 }
-
-#else
-
-#include <cstdlib>
-#include <iostream>
-
-int main() {
-  std::cerr << "Sorry, no MPI library installed on your computer.\n";
-  return EXIT_FAILURE;
-}
-
-#endif
-
